save

Function save 

pub async fn save<P: AsRef<Path>>(
    backup_dirpath: P,
    num_lines_to_drop: usize,
) -> Result<(PathBuf, Overview)>
Save the tmux sessions, windows and panes into a backup at backup_dirpath.

After saving, this function returns the path to the backup and the number of sessions, windows and panes.

Notes

  • The backup_dirpath folder is assumed to exist (done during catalog initialization).
  • Backups have a name similar to backup-20220731T222948.tar.zst.